#
# spec file for package putty
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           putty
Version:        0.68
Release:        13.1
Summary:        GTK-based terminal emulator program
License:        MIT
Group:          System/X11/Utilities
Url:            http://www.chiark.greenend.org.uk/~sgtatham/putty/

#Git-Web:	http://tartarus.org/~simon-git/gitweb/?p=putty.git
#Git-Clone:	git://git.tartarus.org/simon/putty
Source:         http://the.earth.li/~sgtatham/putty/latest/%name-%version.tar.gz
Source2:        http://the.earth.li/~sgtatham/putty/latest/%name-%version.tar.gz.gpg
Source4:        %name.keyring
Patch1:         putty-03-config.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  ImageMagick
BuildRequires:  gtk2-devel
BuildRequires:  krb5-devel
BuildRequires:  update-desktop-files
Conflicts:      pssh

%description
PuTTY is a terminal emulator application which can act as a client
for the SSH, Telnet, rlogin, and raw TCP computing protocols and as a
serial console client.

%prep
%setup -q
%patch -P 1 -p1

%build
%configure
make %{?_smp_mflags}
make %{?_smp_mflags} -C icons cicons pngs

%install
%make_install
b="%buildroot"
mkdir -p "$b/%_datadir/applications/"
cat >"$b/%_datadir/applications/%name.desktop" <<-EOF
	[Desktop Entry]
	Name=PuTTY SSH Client
	GenericName=PuTTY
	Comment=Connect to an SSH server with PuTTY
	Exec=putty
	Icon=putty
	Terminal=false
	Type=Application
	Categories=GTK;Network;RemoteAccess;
EOF

%suse_update_desktop_file -n %name

mkdir -p "$b/%_datadir/pixmaps/"
install -m644 icons/xpmpterm.c "$b/%_datadir/pixmaps/pterm.xpm"
install -m644 icons/xpmputty.c "$b/%_datadir/pixmaps/putty.xpm"
install -m644 icons/pterm-32.png "$b/%_datadir/pixmaps/pterm.png"
install -m644 icons/putty-32.png "$b/%_datadir/pixmaps/putty.png"

%check
make check

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc LICENCE doc/*.html
%doc %_mandir/man*/*
%_bindir/*
%_datadir/applications/%name.desktop
%_datadir/pixmaps/*.png
%_datadir/pixmaps/*.xpm

%changelog
* Wed Mar 15 2017 jengelh@inai.de
- Update to new upstream release 0.68
  * resolve integer overflow in the ssh_agent_channel_data
    [CVE-2017-6542, boo#1029256]
- Drop reproducible.patch, no longer applies
* Tue Mar  8 2016 bwiedemann@suse.com
- Add reproducible.patch to fix build-compare
* Tue Mar  8 2016 jengelh@inai.de
- Update to new upstream release 0.67
  * resolved a security issue with the PSCP protocol implementation
* Mon Nov  9 2015 jengelh@inai.de
- Update to new upstream release 0.66
  * Resolve integer overflow, buffer underrun in terminal emulator's
  ECH handling. [CVE-2015-5309, bnc#954191]
  * Resolve format string vulnerabilities
* Mon Jul 27 2015 jengelh@inai.de
- Update to new upstream release 0.65
  * Cryptography speedup on 64-bit Unix platforms by using gcc and
  clang's __uint128_t built-in type.
  * Bug fix: PSFTP now returns a failure exit status if a command
  fails in a batch-mode script.
  * Bug fix: ESC [ 13 t can no longer elicit an invalid escape
  sequence as a response.
* Wed May 13 2015 aj@ajaissle.de
- Build icons and add a .desktop file for putty
* Mon Mar  2 2015 jengelh@inai.de
- Update to new upstream release 0.64
  * Security fix: PuTTY no longer retains the private half of users'
  keys in memory by mistake after authenticating with them.
  [bnc#920167] (CVE-2015-2157)
  * Support for SSH connection sharing, so that multiple instances of
  PuTTY to the same host can share a single SSH connection instead
  of all having to log in independently.
  * Bug fix: IPv6 literals are handled sensibly throughout the suite,
  if you enclose them in square brackets to prevent the colons
  being mistaken for a :port suffix.
- Remove 0001-Revert-the-default-for-font-bolding-style.patch
  (merged upstream), putty-04-nodate.diff (no longer needed).
* Tue Sep 23 2014 jengelh@inai.de
- Drop gpg-offline build-time requirement; this is now handled by
  the local source validator
* Wed Aug  7 2013 jengelh@inai.de
- Add 0001-Revert-the-default-for-font-bolding-style.patch
  (upstream patch fixing a cosmetic change introduced in 0.63)
- Add Conflict tag against pssh package (Parallel SSH) due to
  conflicting files in /usr/bin
* Tue Aug  6 2013 jengelh@inai.de
- Do signature verification
* Tue Aug  6 2013 andreas.stieger@gmx.de
- update to 0.63
  * Security fix: prevent a nefarious SSH server or network attacker
    from crashing PuTTY at startup in three different ways by
    presenting a maliciously constructed public key and signature.
    [bnc#833567] CVE-2013-4852
  * Security fix: PuTTY no longer retains the private half of users'
    keys in memory by mistake after authenticating with them.
  * Revamped the internal configuration storage system to remove all
    fixed arbitrary limits on string lengths. In particular, there
    should now no longer be an unreasonably small limit on the number
    of port forwardings PuTTY can store.
  * Forwarded TCP connections which close one direction before the
    other should now be reliably supported, with EOF propagated
    independently in the two directions. This also fixes some instances
    of forwarding data corruption (if the corruption consisted of
    losing data from the very end of the connection) and some instances
    of PuTTY failing to close when the session is over (because it
    wrongly thought a forwarding channel was still active when it was
    not).
  * The terminal emulation now supports xterm's bracketed paste mode
    (allowing aware applications to tell the difference between typed
    and pasted text, so that e.g. editors need not apply inappropriate
    auto-indent).
  * You can now choose to display bold text by both brightening the
    foreground colour and changing the font, not just one or the other.
  * PuTTYgen will now never generate a 2047-bit key when asked for 2048
    (or more generally n−1 bits when asked for n).
  * Some updates to default settings: PuTTYgen now generates 2048-bit
    keys by default (rather than 1024), and PuTTY defaults to UTF-8
    encoding and 2000 lines of scrollback (rather than ISO 8859-1 and
    200).
  * Unix: PSCP and PSFTP now preserve the Unix file permissions, on
    copies in both directions.
  * Unix: dead keys and compose-character sequences are now supported.
  * Unix: PuTTY and pterm now permit font fallback (where glyphs not
    present in your selected font are automatically filled in from other
    fonts on the system) even if you are using a server-side X11 font
    rather than a Pango client-side one.
  * Bug fixes too numerous to list, mostly resulting from running the
    code through Coverity Scan which spotted an assortment of memory
    and resource leaks, logic errors, and crashes in various circumstances.
- packaging changes:
  * run make from base directory
  * run tests
  * remove putty-01-werror.diff (currently not needed)
  * remove putty-02-remove-gtk1.diff, putty-05-glib-deprecated.diff,
    putty-06-gtk2-indivhdr.diff (no longer needed)
  * refresh putty-03-config.diff
  * remove autoconf calls and requirements
  * package HTML documentation
  * package LICENCE file
* Sun Dec 11 2011 andreas.stieger@gmx.de
- update to upstream 0.62:
  * Security fix: PuTTY no longer retains passwords in memory by
  mistake.
  * Bug fix: Pageant now talks to both new-style clients (0.61 and
  above) and old-style (0.60 and below).
  * Bug fix: PuTTY no longer prints a spurious "Access denied"
  message when GSSAPI authentication fails.
  * Bug fix: PSCP and PSFTP now honour nonstandard port numbers in
  SSH saved sessions.
  * Bug fix: Pageant no longer leaks a file handle when an
  authentication fails.
  * Bug fix: PuTTYtel no longer crashes when saving a session.
  * Bug fix: PuTTY now draws underlines under the underlined text
  instead of sometimes putting them somewhere off to the right.
  * Bug fix: PuTTY now should not draw VT100 line drawing characters
  at the wrong vertical offset.
- fix SLE build
* Tue Jul 26 2011 jengelh@medozas.de
- Initial package for build.opensuse.org
